@@ -13,7 +13,7 @@ static PyObject* kmerslib_core_makeFFPS(PyObject *self, PyObject *args){
 
 static PyMethodDef kmerslib_core_methods[] = {
 	{"makeFFPS",(PyCFunction)kmerslib_core_makeFFPS,METH_VARARGS, "Calculate Frequency File Profile"},
-	{NULL,}
+	{NULL}
 };
 
 
